"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const randomName = require("@scaleway/random-name");
const json = require("../../../helpers/json.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
require("../../../vendor/base64/index.cjs");
const unmarshalContract = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Contract' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    name: data.name,
    type: data.type,
    updatedAt: marshalling.unmarshalDate(data.updated_at),
    version: data.version
  };
};
const unmarshalContractSignature = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ContractSignature' failed as data isn't a dictionary.`
    );
  }
  return {
    contract: data.contract ? unmarshalContract(data.contract) : void 0,
    createdAt: marshalling.unmarshalDate(data.created_at),
    expiresAt: marshalling.unmarshalDate(data.expires_at),
    id: data.id,
    organizationId: data.organization_id,
    signedAt: marshalling.unmarshalDate(data.signed_at)
  };
};
const unmarshalProject = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Project' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    description: data.description,
    id: data.id,
    name: data.name,
    organizationId: data.organization_id,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalCheckContractSignatureResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'CheckContractSignatureResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    created: data.created,
    validated: data.validated
  };
};
const unmarshalListContractSignaturesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListContractSignaturesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    contractSignatures: marshalling.unmarshalArrayOfObject(
      data.contract_signatures,
      unmarshalContractSignature
    ),
    totalCount: data.total_count
  };
};
const unmarshalListProjectsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListProjectsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    projects: marshalling.unmarshalArrayOfObject(data.projects, unmarshalProject),
    totalCount: data.total_count
  };
};
const marshalContractApiCheckContractSignatureRequest = (request, defaults) => ({
  contract_name: request.contractName,
  contract_type: request.contractType,
  organization_id: request.organizationId ?? defaults.defaultOrganizationId
});
const marshalContractApiCreateContractSignatureRequest = (request, defaults) => ({
  contract_name: request.contractName,
  contract_type: request.contractType,
  organization_id: request.organizationId ?? defaults.defaultOrganizationId,
  validated: request.validated
});
const marshalProjectApiCreateProjectRequest = (request, defaults) => ({
  description: request.description,
  name: request.name || randomName("proj"),
  organization_id: request.organizationId ?? defaults.defaultOrganizationId
});
const marshalProjectApiUpdateProjectRequest = (request, defaults) => ({
  description: request.description,
  name: request.name
});
exports.marshalContractApiCheckContractSignatureRequest = marshalContractApiCheckContractSignatureRequest;
exports.marshalContractApiCreateContractSignatureRequest = marshalContractApiCreateContractSignatureRequest;
exports.marshalProjectApiCreateProjectRequest = marshalProjectApiCreateProjectRequest;
exports.marshalProjectApiUpdateProjectRequest = marshalProjectApiUpdateProjectRequest;
exports.unmarshalCheckContractSignatureResponse = unmarshalCheckContractSignatureResponse;
exports.unmarshalContractSignature = unmarshalContractSignature;
exports.unmarshalListContractSignaturesResponse = unmarshalListContractSignaturesResponse;
exports.unmarshalListProjectsResponse = unmarshalListProjectsResponse;
exports.unmarshalProject = unmarshalProject;
