import randomName from "@scaleway/random-name";
import { isJSONObject } from "../../../helpers/json.js";
import { unmarshalDate, unmarshalArrayOfObject } from "../../../helpers/marshalling.js";
import "../../../vendor/base64/index.js";
const unmarshalContract = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Contract' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: unmarshalDate(data.created_at),
    id: data.id,
    name: data.name,
    type: data.type,
    updatedAt: unmarshalDate(data.updated_at),
    version: data.version
  };
};
const unmarshalContractSignature = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ContractSignature' failed as data isn't a dictionary.`
    );
  }
  return {
    contract: data.contract ? unmarshalContract(data.contract) : void 0,
    createdAt: unmarshalDate(data.created_at),
    expiresAt: unmarshalDate(data.expires_at),
    id: data.id,
    organizationId: data.organization_id,
    signedAt: unmarshalDate(data.signed_at)
  };
};
const unmarshalProject = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Project' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: unmarshalDate(data.created_at),
    description: data.description,
    id: data.id,
    name: data.name,
    organizationId: data.organization_id,
    updatedAt: unmarshalDate(data.updated_at)
  };
};
const unmarshalCheckContractSignatureResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'CheckContractSignatureResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    created: data.created,
    validated: data.validated
  };
};
const unmarshalListContractSignaturesResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListContractSignaturesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    contractSignatures: unmarshalArrayOfObject(
      data.contract_signatures,
      unmarshalContractSignature
    ),
    totalCount: data.total_count
  };
};
const unmarshalListProjectsResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListProjectsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    projects: unmarshalArrayOfObject(data.projects, unmarshalProject),
    totalCount: data.total_count
  };
};
const marshalContractApiCheckContractSignatureRequest = (request, defaults) => ({
  contract_name: request.contractName,
  contract_type: request.contractType,
  organization_id: request.organizationId ?? defaults.defaultOrganizationId
});
const marshalContractApiCreateContractSignatureRequest = (request, defaults) => ({
  contract_name: request.contractName,
  contract_type: request.contractType,
  organization_id: request.organizationId ?? defaults.defaultOrganizationId,
  validated: request.validated
});
const marshalProjectApiCreateProjectRequest = (request, defaults) => ({
  description: request.description,
  name: request.name || randomName("proj"),
  organization_id: request.organizationId ?? defaults.defaultOrganizationId
});
const marshalProjectApiUpdateProjectRequest = (request, defaults) => ({
  description: request.description,
  name: request.name
});
export {
  marshalContractApiCheckContractSignatureRequest,
  marshalContractApiCreateContractSignatureRequest,
  marshalProjectApiCreateProjectRequest,
  marshalProjectApiUpdateProjectRequest,
  unmarshalCheckContractSignatureResponse,
  unmarshalContractSignature,
  unmarshalListContractSignaturesResponse,
  unmarshalListProjectsResponse,
  unmarshalProject
};
