import { API as ParentAPI } from '../../../bridge';
import type { Zone as ScwZone } from '../../../bridge';
import type { ApplyBlockMigrationRequest, AttachServerVolumeRequest, AttachServerVolumeResponse, CheckBlockMigrationOrganizationQuotasRequest, CreateImageRequest, CreateImageResponse, CreateIpRequest, CreateIpResponse, CreatePlacementGroupRequest, CreatePlacementGroupResponse, CreatePrivateNICRequest, CreatePrivateNICResponse, CreateSecurityGroupRequest, CreateSecurityGroupResponse, CreateSecurityGroupRuleRequest, CreateSecurityGroupRuleResponse, CreateServerRequest, CreateServerResponse, CreateSnapshotRequest, CreateSnapshotResponse, CreateVolumeRequest, CreateVolumeResponse, DeleteImageRequest, DeleteIpRequest, DeletePlacementGroupRequest, DeletePrivateNICRequest, DeleteSecurityGroupRequest, DeleteSecurityGroupRuleRequest, DeleteServerRequest, DeleteServerUserDataRequest, DeleteSnapshotRequest, DeleteVolumeRequest, DetachServerVolumeRequest, DetachServerVolumeResponse, ExportSnapshotRequest, ExportSnapshotResponse, GetDashboardRequest, GetDashboardResponse, GetImageRequest, GetImageResponse, GetIpRequest, GetIpResponse, GetPlacementGroupRequest, GetPlacementGroupResponse, GetPlacementGroupServersRequest, GetPlacementGroupServersResponse, GetPrivateNICRequest, GetPrivateNICResponse, GetSecurityGroupRequest, GetSecurityGroupResponse, GetSecurityGroupRuleRequest, GetSecurityGroupRuleResponse, GetServerRequest, GetServerResponse, GetServerTypesAvailabilityRequest, GetServerTypesAvailabilityResponse, GetSnapshotRequest, GetSnapshotResponse, GetVolumeRequest, GetVolumeResponse, ListDefaultSecurityGroupRulesRequest, ListImagesRequest, ListImagesResponse, ListIpsRequest, ListIpsResponse, ListPlacementGroupsRequest, ListPlacementGroupsResponse, ListPrivateNICsRequest, ListPrivateNICsResponse, ListSecurityGroupRulesRequest, ListSecurityGroupRulesResponse, ListSecurityGroupsRequest, ListSecurityGroupsResponse, ListServerActionsRequest, ListServerActionsResponse, ListServerUserDataRequest, ListServerUserDataResponse, ListServersRequest, ListServersResponse, ListServersTypesRequest, ListServersTypesResponse, ListSnapshotsRequest, ListSnapshotsResponse, ListVolumesRequest, ListVolumesResponse, ListVolumesTypesRequest, ListVolumesTypesResponse, MigrationPlan, PlanBlockMigrationRequest, PrivateNIC, ServerActionRequest, ServerActionResponse, SetImageRequest, SetPlacementGroupRequest, SetPlacementGroupResponse, SetPlacementGroupServersRequest, SetPlacementGroupServersResponse, SetSecurityGroupRulesRequest, SetSecurityGroupRulesResponse, UpdateImageRequest, UpdateImageResponse, UpdateIpRequest, UpdateIpResponse, UpdatePlacementGroupRequest, UpdatePlacementGroupResponse, UpdatePlacementGroupServersRequest, UpdatePlacementGroupServersResponse, UpdatePrivateNICRequest, UpdateSecurityGroupRequest, UpdateSecurityGroupResponse, UpdateSecurityGroupRuleRequest, UpdateSecurityGroupRuleResponse, UpdateServerRequest, UpdateServerResponse, UpdateSnapshotRequest, UpdateSnapshotResponse, UpdateVolumeRequest, UpdateVolumeResponse } from './types.gen';
import type { SetImageResponse, SetSecurityGroupRequest, SetSecurityGroupResponse, SetSecurityGroupRuleRequest, SetSecurityGroupRuleResponse, SetServerRequest, SetServerResponse, SetSnapshotRequest, SetSnapshotResponse } from './types.private.gen';
/**
 * Instance API.
 *
 * This API allows you to manage your Instances.
 */
export declare class API extends ParentAPI {
    /** Lists the available zones of the API. */
    static readonly LOCALITIES: ScwZone[];
    /**
     * Get availability. Get availability for all Instance types.
     *
     * @param request - The request {@link GetServerTypesAvailabilityRequest}
     * @returns A Promise of GetServerTypesAvailabilityResponse
     */
    getServerTypesAvailability: (request?: Readonly<GetServerTypesAvailabilityRequest>) => Promise<GetServerTypesAvailabilityResponse>;
    /**
     * List Instance types. List available Instance types and their technical
     * details.
     *
     * @param request - The request {@link ListServersTypesRequest}
     * @returns A Promise of ListServersTypesResponse
     */
    listServersTypes: (request?: Readonly<ListServersTypesRequest>) => Promise<ListServersTypesResponse>;
    /**
     * List volume types. List all volume types and their technical details.
     *
     * @param request - The request {@link ListVolumesTypesRequest}
     * @returns A Promise of ListVolumesTypesResponse
     */
    listVolumesTypes: (request?: Readonly<ListVolumesTypesRequest>) => Promise<ListVolumesTypesResponse>;
    protected pageOfListServers: (request?: Readonly<ListServersRequest>) => Promise<ListServersResponse>;
    /**
     * List all Instances. List all Instances in a specified Availability Zone,
     * e.g. `fr-par-1`.
     *
     * @param request - The request {@link ListServersRequest}
     * @returns A Promise of ListServersResponse
     */
    listServers: (request?: Readonly<ListServersRequest>) => Promise<ListServersResponse> & {
        all: () => Promise<import("./types.gen").Server[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").Server[], void, void>;
    };
    protected _createServer: (request: Readonly<CreateServerRequest>) => Promise<CreateServerResponse>;
    /**
     * Delete an Instance. Delete the Instance with the specified ID.
     *
     * @param request - The request {@link DeleteServerRequest}
     */
    deleteServer: (request: Readonly<DeleteServerRequest>) => Promise<void>;
    /**
     * Get an Instance. Get the details of a specified Instance.
     *
     * @param request - The request {@link GetServerRequest}
     * @returns A Promise of GetServerResponse
     */
    getServer: (request: Readonly<GetServerRequest>) => Promise<GetServerResponse>;
    protected _setServer: (request: Readonly<SetServerRequest>) => Promise<SetServerResponse>;
    protected _updateServer: (request: Readonly<UpdateServerRequest>) => Promise<UpdateServerResponse>;
    /**
     * List Instance actions. List all actions (e.g. power on, power off, reboot)
     * that can currently be performed on an Instance.
     *
     * @param request - The request {@link ListServerActionsRequest}
     * @returns A Promise of ListServerActionsResponse
     */
    listServerActions: (request: Readonly<ListServerActionsRequest>) => Promise<ListServerActionsResponse>;
    /**
     * Perform action. Perform an action on an Instance. Available actions are:
     * `poweron`: Start a stopped Instance. `poweroff`: Fully stop the Instance
     * and release the hypervisor slot. `stop_in_place`: Stop the Instance, but
     * keep the slot on the hypervisor. `reboot`: Stop the instance and restart
     * it. `backup`: Create an image with all the volumes of an Instance.
     * `terminate`: Delete the Instance along with its attached volumes, except
     * for SBS volumes. `enable_routed_ip`: Migrate the Instance to the new
     * network stack.
     *
     * The `terminate` action will result in the deletion of `l_ssd`, `b_ssd` and
     * `scratch` volumes types, `sbs_volume` volumes type will only be detached.
     * If you want to preserve your volumes, you should detach them before the
     * Instance deletion or `terminate` action.
     *
     * The `backup` action can be done with: No `volumes` key in the body: an
     * image is created with snapshots of all the server volumes, except for the
     * `scratch` volumes types. `volumes` key in the body with a dictionary as
     * value, in this dictionary volumes UUID as keys and empty dictionaries as
     * values : an image is created with the snapshots of the volumes in `volumes`
     * key. `scratch` volumes types can't be shapshotted.
     *
     * @param request - The request {@link ServerActionRequest}
     * @returns A Promise of ServerActionResponse
     */
    serverAction: (request: Readonly<ServerActionRequest>) => Promise<ServerActionResponse>;
    /**
     * List user data. List all user data keys registered on a specified Instance.
     *
     * @param request - The request {@link ListServerUserDataRequest}
     * @returns A Promise of ListServerUserDataResponse
     */
    listServerUserData: (request: Readonly<ListServerUserDataRequest>) => Promise<ListServerUserDataResponse>;
    /**
     * Delete user data. Delete the specified key from an Instance's user data.
     *
     * @param request - The request {@link DeleteServerUserDataRequest}
     */
    deleteServerUserData: (request: Readonly<DeleteServerUserDataRequest>) => Promise<void>;
    attachServerVolume: (request: Readonly<AttachServerVolumeRequest>) => Promise<AttachServerVolumeResponse>;
    detachServerVolume: (request: Readonly<DetachServerVolumeRequest>) => Promise<DetachServerVolumeResponse>;
    protected pageOfListImages: (request?: Readonly<ListImagesRequest>) => Promise<ListImagesResponse>;
    /**
     * List Instance images. List all existing Instance images.
     *
     * @param request - The request {@link ListImagesRequest}
     * @returns A Promise of ListImagesResponse
     */
    listImages: (request?: Readonly<ListImagesRequest>) => Promise<ListImagesResponse> & {
        all: () => Promise<import("./types.gen").Image[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").Image[], void, void>;
    };
    /**
     * Get an Instance image. Get details of an image with the specified ID.
     *
     * @param request - The request {@link GetImageRequest}
     * @returns A Promise of GetImageResponse
     */
    getImage: (request: Readonly<GetImageRequest>) => Promise<GetImageResponse>;
    /**
     * Create an Instance image. Create an Instance image from the specified
     * snapshot ID.
     *
     * @param request - The request {@link CreateImageRequest}
     * @returns A Promise of CreateImageResponse
     */
    createImage: (request: Readonly<CreateImageRequest>) => Promise<CreateImageResponse>;
    protected _setImage: (request: Readonly<SetImageRequest>) => Promise<SetImageResponse>;
    /**
     * Update image. Update the properties of an image.
     *
     * @param request - The request {@link UpdateImageRequest}
     * @returns A Promise of UpdateImageResponse
     */
    updateImage: (request: Readonly<UpdateImageRequest>) => Promise<UpdateImageResponse>;
    /**
     * Delete an Instance image. Delete the image with the specified ID.
     *
     * @param request - The request {@link DeleteImageRequest}
     */
    deleteImage: (request: Readonly<DeleteImageRequest>) => Promise<void>;
    protected pageOfListSnapshots: (request?: Readonly<ListSnapshotsRequest>) => Promise<ListSnapshotsResponse>;
    /**
     * List snapshots. List all snapshots of an Organization in a specified
     * Availability Zone.
     *
     * @param request - The request {@link ListSnapshotsRequest}
     * @returns A Promise of ListSnapshotsResponse
     */
    listSnapshots: (request?: Readonly<ListSnapshotsRequest>) => Promise<ListSnapshotsResponse> & {
        all: () => Promise<import("./types.gen").Snapshot[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").Snapshot[], void, void>;
    };
    /**
     * Create a snapshot from a specified volume or from a QCOW2 file. Create a
     * snapshot from a specified volume or from a QCOW2 file in a specified
     * Availability Zone.
     *
     * @param request - The request {@link CreateSnapshotRequest}
     * @returns A Promise of CreateSnapshotResponse
     */
    createSnapshot: (request?: Readonly<CreateSnapshotRequest>) => Promise<CreateSnapshotResponse>;
    /**
     * Get a snapshot. Get details of a snapshot with the specified ID.
     *
     * @param request - The request {@link GetSnapshotRequest}
     * @returns A Promise of GetSnapshotResponse
     */
    getSnapshot: (request: Readonly<GetSnapshotRequest>) => Promise<GetSnapshotResponse>;
    protected _setSnapshot: (request: Readonly<SetSnapshotRequest>) => Promise<SetSnapshotResponse>;
    /**
     * Update a snapshot. Update the properties of a snapshot.
     *
     * @param request - The request {@link UpdateSnapshotRequest}
     * @returns A Promise of UpdateSnapshotResponse
     */
    updateSnapshot: (request: Readonly<UpdateSnapshotRequest>) => Promise<UpdateSnapshotResponse>;
    /**
     * Delete a snapshot. Delete the snapshot with the specified ID.
     *
     * @param request - The request {@link DeleteSnapshotRequest}
     */
    deleteSnapshot: (request: Readonly<DeleteSnapshotRequest>) => Promise<void>;
    /**
     * Export a snapshot. Export a snapshot to a specified Object Storage bucket
     * in the same region.
     *
     * @param request - The request {@link ExportSnapshotRequest}
     * @returns A Promise of ExportSnapshotResponse
     */
    exportSnapshot: (request: Readonly<ExportSnapshotRequest>) => Promise<ExportSnapshotResponse>;
    protected pageOfListVolumes: (request?: Readonly<ListVolumesRequest>) => Promise<ListVolumesResponse>;
    /**
     * List volumes. List volumes in the specified Availability Zone. You can
     * filter the output by volume type.
     *
     * @param request - The request {@link ListVolumesRequest}
     * @returns A Promise of ListVolumesResponse
     */
    listVolumes: (request?: Readonly<ListVolumesRequest>) => Promise<ListVolumesResponse> & {
        all: () => Promise<import("./types.gen").Volume[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").Volume[], void, void>;
    };
    /**
     * Create a volume. Create a volume of a specified type in an Availability
     * Zone.
     *
     * @param request - The request {@link CreateVolumeRequest}
     * @returns A Promise of CreateVolumeResponse
     */
    createVolume: (request?: Readonly<CreateVolumeRequest>) => Promise<CreateVolumeResponse>;
    /**
     * Get a volume. Get details of a volume with the specified ID.
     *
     * @param request - The request {@link GetVolumeRequest}
     * @returns A Promise of GetVolumeResponse
     */
    getVolume: (request: Readonly<GetVolumeRequest>) => Promise<GetVolumeResponse>;
    /**
     * Update a volume. Replace the name and/or size properties of a volume
     * specified by its ID, with the specified value(s). Any volume name can be
     * changed, however only `b_ssd` volumes can currently be increased in size.
     *
     * @param request - The request {@link UpdateVolumeRequest}
     * @returns A Promise of UpdateVolumeResponse
     */
    updateVolume: (request: Readonly<UpdateVolumeRequest>) => Promise<UpdateVolumeResponse>;
    /**
     * Delete a volume. Delete the volume with the specified ID.
     *
     * @param request - The request {@link DeleteVolumeRequest}
     */
    deleteVolume: (request: Readonly<DeleteVolumeRequest>) => Promise<void>;
    protected pageOfListSecurityGroups: (request?: Readonly<ListSecurityGroupsRequest>) => Promise<ListSecurityGroupsResponse>;
    /**
     * List security groups. List all existing security groups.
     *
     * @param request - The request {@link ListSecurityGroupsRequest}
     * @returns A Promise of ListSecurityGroupsResponse
     */
    listSecurityGroups: (request?: Readonly<ListSecurityGroupsRequest>) => Promise<ListSecurityGroupsResponse> & {
        all: () => Promise<import("./types.gen").SecurityGroup[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").SecurityGroup[], void, void>;
    };
    /**
     * Create a security group. Create a security group with a specified name and
     * description.
     *
     * @param request - The request {@link CreateSecurityGroupRequest}
     * @returns A Promise of CreateSecurityGroupResponse
     */
    createSecurityGroup: (request: Readonly<CreateSecurityGroupRequest>) => Promise<CreateSecurityGroupResponse>;
    /**
     * Get a security group. Get the details of a security group with the
     * specified ID.
     *
     * @param request - The request {@link GetSecurityGroupRequest}
     * @returns A Promise of GetSecurityGroupResponse
     */
    getSecurityGroup: (request: Readonly<GetSecurityGroupRequest>) => Promise<GetSecurityGroupResponse>;
    /**
     * Delete a security group. Delete a security group with the specified ID.
     *
     * @param request - The request {@link DeleteSecurityGroupRequest}
     */
    deleteSecurityGroup: (request: Readonly<DeleteSecurityGroupRequest>) => Promise<void>;
    protected _setSecurityGroup: (request: Readonly<SetSecurityGroupRequest>) => Promise<SetSecurityGroupResponse>;
    /**
     * Update a security group. Update the properties of security group.
     *
     * @param request - The request {@link UpdateSecurityGroupRequest}
     * @returns A Promise of UpdateSecurityGroupResponse
     */
    updateSecurityGroup: (request: Readonly<UpdateSecurityGroupRequest>) => Promise<UpdateSecurityGroupResponse>;
    /**
     * Get default rules. Lists the default rules applied to all the security
     * groups.
     *
     * @param request - The request {@link ListDefaultSecurityGroupRulesRequest}
     * @returns A Promise of ListSecurityGroupRulesResponse
     */
    listDefaultSecurityGroupRules: (request?: Readonly<ListDefaultSecurityGroupRulesRequest>) => Promise<ListSecurityGroupRulesResponse>;
    protected pageOfListSecurityGroupRules: (request: Readonly<ListSecurityGroupRulesRequest>) => Promise<ListSecurityGroupRulesResponse>;
    /**
     * List rules. List the rules of the a specified security group ID.
     *
     * @param request - The request {@link ListSecurityGroupRulesRequest}
     * @returns A Promise of ListSecurityGroupRulesResponse
     */
    listSecurityGroupRules: (request: Readonly<ListSecurityGroupRulesRequest>) => Promise<ListSecurityGroupRulesResponse> & {
        all: () => Promise<import("./types.gen").SecurityGroupRule[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").SecurityGroupRule[], void, void>;
    };
    /**
     * Create rule. Create a rule in the specified security group ID.
     *
     * @param request - The request {@link CreateSecurityGroupRuleRequest}
     * @returns A Promise of CreateSecurityGroupRuleResponse
     */
    createSecurityGroupRule: (request: Readonly<CreateSecurityGroupRuleRequest>) => Promise<CreateSecurityGroupRuleResponse>;
    /**
     * Update all the rules of a security group. Replaces the existing rules of
     * the security group with the rules provided. This endpoint supports the
     * update of existing rules, creation of new rules and deletion of existing
     * rules when they are not passed in the request.
     *
     * @param request - The request {@link SetSecurityGroupRulesRequest}
     * @returns A Promise of SetSecurityGroupRulesResponse
     */
    setSecurityGroupRules: (request: Readonly<SetSecurityGroupRulesRequest>) => Promise<SetSecurityGroupRulesResponse>;
    /**
     * Delete rule. Delete a security group rule with the specified ID.
     *
     * @param request - The request {@link DeleteSecurityGroupRuleRequest}
     */
    deleteSecurityGroupRule: (request: Readonly<DeleteSecurityGroupRuleRequest>) => Promise<void>;
    /**
     * Get rule. Get details of a security group rule with the specified ID.
     *
     * @param request - The request {@link GetSecurityGroupRuleRequest}
     * @returns A Promise of GetSecurityGroupRuleResponse
     */
    getSecurityGroupRule: (request: Readonly<GetSecurityGroupRuleRequest>) => Promise<GetSecurityGroupRuleResponse>;
    protected _setSecurityGroupRule: (request: Readonly<SetSecurityGroupRuleRequest>) => Promise<SetSecurityGroupRuleResponse>;
    /**
     * Update security group rule. Update the properties of a rule from a
     * specified security group.
     *
     * @param request - The request {@link UpdateSecurityGroupRuleRequest}
     * @returns A Promise of UpdateSecurityGroupRuleResponse
     */
    updateSecurityGroupRule: (request: Readonly<UpdateSecurityGroupRuleRequest>) => Promise<UpdateSecurityGroupRuleResponse>;
    protected pageOfListPlacementGroups: (request?: Readonly<ListPlacementGroupsRequest>) => Promise<ListPlacementGroupsResponse>;
    /**
     * List placement groups. List all placement groups in a specified
     * Availability Zone.
     *
     * @param request - The request {@link ListPlacementGroupsRequest}
     * @returns A Promise of ListPlacementGroupsResponse
     */
    listPlacementGroups: (request?: Readonly<ListPlacementGroupsRequest>) => Promise<ListPlacementGroupsResponse> & {
        all: () => Promise<import("./types.gen").PlacementGroup[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").PlacementGroup[], void, void>;
    };
    /**
     * Create a placement group. Create a new placement group in a specified
     * Availability Zone.
     *
     * @param request - The request {@link CreatePlacementGroupRequest}
     * @returns A Promise of CreatePlacementGroupResponse
     */
    createPlacementGroup: (request?: Readonly<CreatePlacementGroupRequest>) => Promise<CreatePlacementGroupResponse>;
    /**
     * Get a placement group. Get the specified placement group.
     *
     * @param request - The request {@link GetPlacementGroupRequest}
     * @returns A Promise of GetPlacementGroupResponse
     */
    getPlacementGroup: (request: Readonly<GetPlacementGroupRequest>) => Promise<GetPlacementGroupResponse>;
    /**
     * Set placement group. Set all parameters of the specified placement group.
     *
     * @param request - The request {@link SetPlacementGroupRequest}
     * @returns A Promise of SetPlacementGroupResponse
     */
    setPlacementGroup: (request: Readonly<SetPlacementGroupRequest>) => Promise<SetPlacementGroupResponse>;
    /**
     * Update a placement group. Update one or more parameter of the specified
     * placement group.
     *
     * @param request - The request {@link UpdatePlacementGroupRequest}
     * @returns A Promise of UpdatePlacementGroupResponse
     */
    updatePlacementGroup: (request: Readonly<UpdatePlacementGroupRequest>) => Promise<UpdatePlacementGroupResponse>;
    /**
     * Delete the specified placement group.
     *
     * @param request - The request {@link DeletePlacementGroupRequest}
     */
    deletePlacementGroup: (request: Readonly<DeletePlacementGroupRequest>) => Promise<void>;
    /**
     * Get placement group servers. Get all Instances belonging to the specified
     * placement group.
     *
     * @param request - The request {@link GetPlacementGroupServersRequest}
     * @returns A Promise of GetPlacementGroupServersResponse
     */
    getPlacementGroupServers: (request: Readonly<GetPlacementGroupServersRequest>) => Promise<GetPlacementGroupServersResponse>;
    /**
     * Set placement group servers. Set all Instances belonging to the specified
     * placement group.
     *
     * @param request - The request {@link SetPlacementGroupServersRequest}
     * @returns A Promise of SetPlacementGroupServersResponse
     */
    setPlacementGroupServers: (request: Readonly<SetPlacementGroupServersRequest>) => Promise<SetPlacementGroupServersResponse>;
    /**
     * Update placement group servers. Update all Instances belonging to the
     * specified placement group.
     *
     * @param request - The request {@link UpdatePlacementGroupServersRequest}
     * @returns A Promise of UpdatePlacementGroupServersResponse
     */
    updatePlacementGroupServers: (request: Readonly<UpdatePlacementGroupServersRequest>) => Promise<UpdatePlacementGroupServersResponse>;
    protected pageOfListIps: (request?: Readonly<ListIpsRequest>) => Promise<ListIpsResponse>;
    /**
     * List all flexible IPs. List all flexible IPs in a specified zone.
     *
     * @param request - The request {@link ListIpsRequest}
     * @returns A Promise of ListIpsResponse
     */
    listIps: (request?: Readonly<ListIpsRequest>) => Promise<ListIpsResponse> & {
        all: () => Promise<import("./types.gen").Ip[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").Ip[], void, void>;
    };
    /**
     * Reserve a flexible IP. Reserve a flexible IP and attach it to the specified
     * Instance.
     *
     * @param request - The request {@link CreateIpRequest}
     * @returns A Promise of CreateIpResponse
     */
    createIp: (request?: Readonly<CreateIpRequest>) => Promise<CreateIpResponse>;
    /**
     * Get a flexible IP. Get details of an IP with the specified ID or address.
     *
     * @param request - The request {@link GetIpRequest}
     * @returns A Promise of GetIpResponse
     */
    getIp: (request: Readonly<GetIpRequest>) => Promise<GetIpResponse>;
    /**
     * Update a flexible IP. Update a flexible IP in the specified zone with the
     * specified ID.
     *
     * @param request - The request {@link UpdateIpRequest}
     * @returns A Promise of UpdateIpResponse
     */
    updateIp: (request: Readonly<UpdateIpRequest>) => Promise<UpdateIpResponse>;
    /**
     * Delete a flexible IP. Delete the IP with the specified ID.
     *
     * @param request - The request {@link DeleteIpRequest}
     */
    deleteIp: (request: Readonly<DeleteIpRequest>) => Promise<void>;
    protected pageOfListPrivateNICs: (request: Readonly<ListPrivateNICsRequest>) => Promise<ListPrivateNICsResponse>;
    /**
     * List all private NICs. List all private NICs of a specified Instance.
     *
     * @param request - The request {@link ListPrivateNICsRequest}
     * @returns A Promise of ListPrivateNICsResponse
     */
    listPrivateNICs: (request: Readonly<ListPrivateNICsRequest>) => Promise<ListPrivateNICsResponse> & {
        all: () => Promise<PrivateNIC[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<PrivateNIC[], void, void>;
    };
    /**
     * Create a private NIC connecting an Instance to a Private Network.
     *
     * @param request - The request {@link CreatePrivateNICRequest}
     * @returns A Promise of CreatePrivateNICResponse
     */
    createPrivateNIC: (request: Readonly<CreatePrivateNICRequest>) => Promise<CreatePrivateNICResponse>;
    /**
     * Get a private NIC. Get private NIC properties.
     *
     * @param request - The request {@link GetPrivateNICRequest}
     * @returns A Promise of GetPrivateNICResponse
     */
    getPrivateNIC: (request: Readonly<GetPrivateNICRequest>) => Promise<GetPrivateNICResponse>;
    /**
     * Update a private NIC. Update one or more parameter(s) of a specified
     * private NIC.
     *
     * @param request - The request {@link UpdatePrivateNICRequest}
     * @returns A Promise of PrivateNIC
     */
    updatePrivateNIC: (request: Readonly<UpdatePrivateNICRequest>) => Promise<PrivateNIC>;
    /**
     * Delete a private NIC.
     *
     * @param request - The request {@link DeletePrivateNICRequest}
     */
    deletePrivateNIC: (request: Readonly<DeletePrivateNICRequest>) => Promise<void>;
    getDashboard: (request?: Readonly<GetDashboardRequest>) => Promise<GetDashboardResponse>;
    /**
     * Get a volume or snapshot's migration plan. Given a volume or snapshot,
     * returns the migration plan but does not perform the actual migration. To
     * perform the migration, you have to call the [Migrate a volume and/or
     * snapshots to
     * SBS](#path-volumes-migrate-a-volume-andor-snapshots-to-sbs-scaleway-block-storage)
     * endpoint afterward. The endpoint returns the resources that should be
     * migrated together:
     *
     * - The volume and any snapshots created from the volume, if the call was made
     *   to plan a volume migration.
     * - The base volume of the snapshot (if the volume is not deleted) and its
     *   related snapshots, if the call was made to plan a snapshot migration. The
     *   endpoint also returns the validation_key, which must be provided to the
     *   [Migrate a volume and/or snapshots to
     *   SBS](#path-volumes-migrate-a-volume-andor-snapshots-to-sbs-scaleway-block-storage)
     *   endpoint to confirm that all resources listed in the plan should be
     *   migrated.
     *
     * @param request - The request {@link PlanBlockMigrationRequest}
     * @returns A Promise of MigrationPlan
     */
    planBlockMigration: (request?: Readonly<PlanBlockMigrationRequest>) => Promise<MigrationPlan>;
    /**
     * Migrate a volume and/or snapshots to SBS (Scaleway Block Storage). To be
     * used, the call to this endpoint must be preceded by a call to the [Get a
     * volume or snapshot's migration
     * plan](#path-volumes-get-a-volume-or-snapshots-migration-plan) endpoint. To
     * migrate all resources mentioned in the migration plan, the validation_key
     * returned in the plan must be provided.
     *
     * @param request - The request {@link ApplyBlockMigrationRequest}
     */
    applyBlockMigration: (request: Readonly<ApplyBlockMigrationRequest>) => Promise<void>;
    checkBlockMigrationOrganizationQuotas: (request?: Readonly<CheckBlockMigrationOrganizationQuotasRequest>) => Promise<void>;
}
