import { API as ParentAPI } from '../../../bridge';
import type { Zone as ScwZone, WaitForOptions } from '../../../bridge';
import type { ACLRule, AddAclRulesRequest, AddAclRulesResponse, AddClusterSettingsRequest, AddEndpointsRequest, AddEndpointsResponse, Cluster, ClusterMetricsResponse, ClusterSettingsResponse, CreateClusterRequest, DeleteAclRuleRequest, DeleteClusterRequest, DeleteClusterSettingRequest, DeleteEndpointRequest, Endpoint, GetAclRuleRequest, GetClusterCertificateRequest, GetClusterMetricsRequest, GetClusterRequest, GetEndpointRequest, ListClusterVersionsRequest, ListClusterVersionsResponse, ListClustersRequest, ListClustersResponse, ListNodeTypesRequest, ListNodeTypesResponse, MigrateClusterRequest, RenewClusterCertificateRequest, SetAclRulesRequest, SetAclRulesResponse, SetClusterSettingsRequest, SetEndpointsRequest, SetEndpointsResponse, UpdateClusterRequest, UpdateEndpointRequest } from './types.gen';
/**
 * Managed Database for Redis™ API.
 *
 * This API allows you to manage your Managed Databases for Redis™.
 */
export declare class API extends ParentAPI {
    /** Lists the available zones of the API. */
    static readonly LOCALITIES: ScwZone[];
    /**
     * Create a Redis™ Database Instance. Create a new Redis™ Database Instance
     * (Redis™ cluster). You must set the `zone`, `project_id`, `version`,
     * `node_type`, `user_name` and `password` parameters. Optionally you can
     * define `acl_rules`, `endpoints`, `tls_enabled` and `cluster_settings`.
     *
     * @param request - The request {@link CreateClusterRequest}
     * @returns A Promise of Cluster
     */
    createCluster: (request: Readonly<CreateClusterRequest>) => Promise<Cluster>;
    /**
     * Update a Redis™ Database Instance. Update the parameters of a Redis™
     * Database Instance (Redis™ cluster), including `name`, `tags`, `user_name`
     * and `password`.
     *
     * @param request - The request {@link UpdateClusterRequest}
     * @returns A Promise of Cluster
     */
    updateCluster: (request: Readonly<UpdateClusterRequest>) => Promise<Cluster>;
    /**
     * Get a Redis™ Database Instance. Retrieve information about a Redis™
     * Database Instance (Redis™ cluster). Specify the `cluster_id` and `region`
     * in your request to get information such as `id`, `status`, `version`,
     * `tls_enabled`, `cluster_settings`, `upgradable_versions` and `endpoints`
     * about your cluster in the response.
     *
     * @param request - The request {@link GetClusterRequest}
     * @returns A Promise of Cluster
     */
    getCluster: (request: Readonly<GetClusterRequest>) => Promise<Cluster>;
    /**
     * Waits for {@link Cluster} to be in a final state.
     *
     * @param request - The request {@link GetClusterRequest}
     * @param options - The waiting options
     * @returns A Promise of Cluster
     */
    waitForCluster: (request: Readonly<GetClusterRequest>, options?: Readonly<WaitForOptions<Cluster>>) => Promise<Cluster>;
    protected pageOfListClusters: (request?: Readonly<ListClustersRequest>) => Promise<ListClustersResponse>;
    /**
     * List Redis™ Database Instances. List all Redis™ Database Instances (Redis™
     * cluster) in the specified zone. By default, the Database Instances returned
     * in the list are ordered by creation date in ascending order, though this
     * can be modified via the order_by field. You can define additional
     * parameters for your query, such as `tags`, `name`, `organization_id` and
     * `version`.
     *
     * @param request - The request {@link ListClustersRequest}
     * @returns A Promise of ListClustersResponse
     */
    listClusters: (request?: Readonly<ListClustersRequest>) => Promise<ListClustersResponse> & {
        all: () => Promise<Cluster[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Cluster[], void, void>;
    };
    /**
     * Scale up a Redis™ Database Instance. Upgrade your Redis™ Database Instance,
     * either by upgrading to a bigger node type (vertical scaling) or by adding
     * more nodes to your Database Instance to increase your number of endpoints
     * and distribute cache (horizontal scaling, available for clusters only).
     * Note that scaling horizontally your Redis™ Database Instance will not renew
     * its TLS certificate. In order to refresh the TLS certificate, you must use
     * the Renew TLS certificate endpoint.
     *
     * @param request - The request {@link MigrateClusterRequest}
     * @returns A Promise of Cluster
     */
    migrateCluster: (request: Readonly<MigrateClusterRequest>) => Promise<Cluster>;
    /**
     * Delete a Redis™ Database Instance. Delete a Redis™ Database Instance
     * (Redis™ cluster), specified by the `region` and `cluster_id` parameters.
     * Deleting a Database Instance is permanent, and cannot be undone. Note that
     * upon deletion all your data will be lost.
     *
     * @param request - The request {@link DeleteClusterRequest}
     * @returns A Promise of Cluster
     */
    deleteCluster: (request: Readonly<DeleteClusterRequest>) => Promise<Cluster>;
    /**
     * Get metrics of a Redis™ Database Instance. Retrieve the metrics of a Redis™
     * Database Instance (Redis™ cluster). You can define the period from which to
     * retrieve metrics by specifying the `start_date` and `end_date`.
     *
     * @param request - The request {@link GetClusterMetricsRequest}
     * @returns A Promise of ClusterMetricsResponse
     */
    getClusterMetrics: (request: Readonly<GetClusterMetricsRequest>) => Promise<ClusterMetricsResponse>;
    protected pageOfListNodeTypes: (request: Readonly<ListNodeTypesRequest>) => Promise<ListNodeTypesResponse>;
    /**
     * List available node types. List all available node types. By default, the
     * node types returned in the list are ordered by creation date in ascending
     * order, though this can be modified via the `order_by` field.
     *
     * @param request - The request {@link ListNodeTypesRequest}
     * @returns A Promise of ListNodeTypesResponse
     */
    listNodeTypes: (request: Readonly<ListNodeTypesRequest>) => Promise<ListNodeTypesResponse> & {
        all: () => Promise<import("./types.gen").NodeType[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").NodeType[], void, void>;
    };
    protected pageOfListClusterVersions: (request: Readonly<ListClusterVersionsRequest>) => Promise<ListClusterVersionsResponse>;
    /**
     * List available Redis™ versions. List the Redis™ database engine versions
     * available. You can define additional parameters for your query, such as
     * `include_disabled`, `include_beta`, `include_deprecated` and `version`.
     *
     * @param request - The request {@link ListClusterVersionsRequest}
     * @returns A Promise of ListClusterVersionsResponse
     */
    listClusterVersions: (request: Readonly<ListClusterVersionsRequest>) => Promise<ListClusterVersionsResponse> & {
        all: () => Promise<import("./types.gen").ClusterVersion[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").ClusterVersion[], void, void>;
    };
    /**
     * Get the TLS certificate of a cluster. Retrieve information about the TLS
     * certificate of a Redis™ Database Instance (Redis™ cluster). Details like
     * name and content are returned in the response.
     *
     * @param request - The request {@link GetClusterCertificateRequest}
     * @returns A Promise of Blob
     */
    getClusterCertificate: (request: Readonly<GetClusterCertificateRequest>) => Promise<Blob>;
    /**
     * Renew the TLS certificate of a cluster. Renew a TLS certificate for a
     * Redis™ Database Instance (Redis™ cluster). Renewing a certificate means
     * that you will not be able to connect to your Database Instance using the
     * previous certificate. You will also need to download and update the new
     * certificate for all database clients.
     *
     * @param request - The request {@link RenewClusterCertificateRequest}
     * @returns A Promise of Cluster
     */
    renewClusterCertificate: (request: Readonly<RenewClusterCertificateRequest>) => Promise<Cluster>;
    /**
     * Add advanced settings. Add an advanced setting to a Redis™ Database
     * Instance (Redis™ cluster). You must set the `name` and the `value` of each
     * setting.
     *
     * @param request - The request {@link AddClusterSettingsRequest}
     * @returns A Promise of ClusterSettingsResponse
     */
    addClusterSettings: (request: Readonly<AddClusterSettingsRequest>) => Promise<ClusterSettingsResponse>;
    /**
     * Delete advanced setting. Delete an advanced setting in a Redis™ Database
     * Instance (Redis™ cluster). You must specify the names of the settings you
     * want to delete in the request body.
     *
     * @param request - The request {@link DeleteClusterSettingRequest}
     * @returns A Promise of Cluster
     */
    deleteClusterSetting: (request: Readonly<DeleteClusterSettingRequest>) => Promise<Cluster>;
    /**
     * Set advanced settings. Update an advanced setting for a Redis™ Database
     * Instance (Redis™ cluster). Settings added upon database engine
     * initalization can only be defined once, and cannot, therefore, be updated.
     *
     * @param request - The request {@link SetClusterSettingsRequest}
     * @returns A Promise of ClusterSettingsResponse
     */
    setClusterSettings: (request: Readonly<SetClusterSettingsRequest>) => Promise<ClusterSettingsResponse>;
    /**
     * Set ACL rules for a cluster. Replace all the ACL rules of a Redis™ Database
     * Instance (Redis™ cluster).
     *
     * @param request - The request {@link SetAclRulesRequest}
     * @returns A Promise of SetAclRulesResponse
     */
    setAclRules: (request: Readonly<SetAclRulesRequest>) => Promise<SetAclRulesResponse>;
    /**
     * Add ACL rules for a cluster. Add an additional ACL rule to a Redis™
     * Database Instance (Redis™ cluster).
     *
     * @param request - The request {@link AddAclRulesRequest}
     * @returns A Promise of AddAclRulesResponse
     */
    addAclRules: (request: Readonly<AddAclRulesRequest>) => Promise<AddAclRulesResponse>;
    /**
     * Delete an ACL rule for a cluster. Delete an ACL rule of a Redis™ Database
     * Instance (Redis™ cluster). You must specify the `acl_id` of the rule you
     * want to delete in your request.
     *
     * @param request - The request {@link DeleteAclRuleRequest}
     * @returns A Promise of Cluster
     */
    deleteAclRule: (request: Readonly<DeleteAclRuleRequest>) => Promise<Cluster>;
    /**
     * Get an ACL rule. Retrieve information about an ACL rule of a Redis™
     * Database Instance (Redis™ cluster). You must specify the `acl_id` of the
     * rule in your request.
     *
     * @param request - The request {@link GetAclRuleRequest}
     * @returns A Promise of ACLRule
     */
    getAclRule: (request: Readonly<GetAclRuleRequest>) => Promise<ACLRule>;
    /**
     * Set endpoints for a cluster. Update an endpoint for a Redis™ Database
     * Instance (Redis™ cluster). You must specify the `cluster_id` and the
     * `endpoints` parameters in your request.
     *
     * @param request - The request {@link SetEndpointsRequest}
     * @returns A Promise of SetEndpointsResponse
     */
    setEndpoints: (request: Readonly<SetEndpointsRequest>) => Promise<SetEndpointsResponse>;
    /**
     * Add endpoints for a cluster. Add a new endpoint for a Redis™ Database
     * Instance (Redis™ cluster). You can add `private_network` or
     * `public_network` specifications to the body of the request.
     *
     * @param request - The request {@link AddEndpointsRequest}
     * @returns A Promise of AddEndpointsResponse
     */
    addEndpoints: (request: Readonly<AddEndpointsRequest>) => Promise<AddEndpointsResponse>;
    /**
     * Delete an endpoint for a cluster. Delete the endpoint of a Redis™ Database
     * Instance (Redis™ cluster). You must specify the `region` and `endpoint_id`
     * parameters of the endpoint you want to delete. Note that might need to
     * update any environment configurations that point to the deleted endpoint.
     *
     * @param request - The request {@link DeleteEndpointRequest}
     * @returns A Promise of Cluster
     */
    deleteEndpoint: (request: Readonly<DeleteEndpointRequest>) => Promise<Cluster>;
    /**
     * Get an endpoint. Retrieve information about a Redis™ Database Instance
     * (Redis™ cluster) endpoint. Full details about the endpoint, like `ips`,
     * `port`, `private_network` and `public_network` specifications are returned
     * in the response.
     *
     * @param request - The request {@link GetEndpointRequest}
     * @returns A Promise of Endpoint
     */
    getEndpoint: (request: Readonly<GetEndpointRequest>) => Promise<Endpoint>;
    /**
     * Update an endpoint. Update information about a Redis™ Database Instance
     * (Redis™ cluster) endpoint. Full details about the endpoint, like `ips`,
     * `port`, `private_network` and `public_network` specifications are returned
     * in the response.
     *
     * @param request - The request {@link UpdateEndpointRequest}
     * @returns A Promise of Endpoint
     */
    updateEndpoint: (request: Readonly<UpdateEndpointRequest>) => Promise<Endpoint>;
}
