import { API as ParentAPI } from '../../../bridge';
import type { Region as ScwRegion, WaitForOptions } from '../../../bridge';
import type { CheckUserOwnsDomainRequest, CheckUserOwnsDomainResponse, ClassicMailApiCreateMailboxRequest, ClassicMailApiDeleteMailboxRequest, ClassicMailApiGetMailboxRequest, ClassicMailApiListMailboxesRequest, ClassicMailApiUpdateMailboxRequest, CreateHostingRequest, CreateSessionRequest, DeleteHostingRequest, DnsRecords, GetDomainDnsRecordsRequest, GetHostingRequest, Hosting, ListControlPanelsRequest, ListControlPanelsResponse, ListHostingsRequest, ListHostingsResponse, ListMailboxesResponse, ListOffersRequest, ListOffersResponse, Mailbox, ResetHostingPasswordRequest, ResetHostingPasswordResponse, RestoreHostingRequest, Session, UpdateHostingRequest } from './types.gen';
/**
 * Web Hosting API.
 *
 * This API allows you to manage your Web Hosting services.
 */
export declare class API extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: ScwRegion[];
    /**
     * Order a Web Hosting plan. Order a Web Hosting plan, specifying the offer
     * type required via the `offer_id` parameter.
     *
     * @param request - The request {@link CreateHostingRequest}
     * @returns A Promise of Hosting
     */
    createHosting: (request: Readonly<CreateHostingRequest>) => Promise<Hosting>;
    protected pageOfListHostings: (request?: Readonly<ListHostingsRequest>) => Promise<ListHostingsResponse>;
    /**
     * List all Web Hosting plans. List all of your existing Web Hosting plans.
     * Various filters are available to limit the results, including filtering by
     * domain, status, tag and Project ID.
     *
     * @param request - The request {@link ListHostingsRequest}
     * @returns A Promise of ListHostingsResponse
     */
    listHostings: (request?: Readonly<ListHostingsRequest>) => Promise<ListHostingsResponse> & {
        all: () => Promise<Hosting[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Hosting[], void, void>;
    };
    /**
     * Get a Web Hosting plan. Get the details of one of your existing Web Hosting
     * plans, specified by its `hosting_id`.
     *
     * @param request - The request {@link GetHostingRequest}
     * @returns A Promise of Hosting
     */
    getHosting: (request: Readonly<GetHostingRequest>) => Promise<Hosting>;
    /**
     * Waits for {@link Hosting} to be in a final state.
     *
     * @param request - The request {@link GetHostingRequest}
     * @param options - The waiting options
     * @returns A Promise of Hosting
     */
    waitForHosting: (request: Readonly<GetHostingRequest>, options?: Readonly<WaitForOptions<Hosting>>) => Promise<Hosting>;
    /**
     * Update a Web Hosting plan. Update the details of one of your existing Web
     * Hosting plans, specified by its `hosting_id`. You can update parameters
     * including the contact email address, tags, options and offer.
     *
     * @param request - The request {@link UpdateHostingRequest}
     * @returns A Promise of Hosting
     */
    updateHosting: (request: Readonly<UpdateHostingRequest>) => Promise<Hosting>;
    /**
     * Delete a Web Hosting plan. Delete a Web Hosting plan, specified by its
     * `hosting_id`. Note that deletion is not immediate: it will take place at
     * the end of the calendar month, after which time your Web Hosting plan and
     * all its data (files and emails) will be irreversibly lost.
     *
     * @param request - The request {@link DeleteHostingRequest}
     * @returns A Promise of Hosting
     */
    deleteHosting: (request: Readonly<DeleteHostingRequest>) => Promise<Hosting>;
    /**
     * Restore a Web Hosting plan. When you [delete a Web Hosting
     * plan](#path-hostings-delete-a-hosting), definitive deletion does not take
     * place until the end of the calendar month. In the time between initiating
     * the deletion, and definitive deletion at the end of the month, you can
     * choose to **restore** the Web Hosting plan, using this endpoint and
     * specifying its `hosting_id`.
     *
     * @param request - The request {@link RestoreHostingRequest}
     * @returns A Promise of Hosting
     */
    restoreHosting: (request: Readonly<RestoreHostingRequest>) => Promise<Hosting>;
    /**
     * Get DNS records. Get the set of DNS records of a specified domain
     * associated with a Web Hosting plan.
     *
     * @param request - The request {@link GetDomainDnsRecordsRequest}
     * @returns A Promise of DnsRecords
     */
    getDomainDnsRecords: (request: Readonly<GetDomainDnsRecordsRequest>) => Promise<DnsRecords>;
    /**
     * "Check whether you own this domain or not.".
     *
     * @param request - The request {@link CheckUserOwnsDomainRequest}
     * @returns A Promise of CheckUserOwnsDomainResponse
     */
    checkUserOwnsDomain: (request: Readonly<CheckUserOwnsDomainRequest>) => Promise<CheckUserOwnsDomainResponse>;
    /**
     * List all offers. List the different Web Hosting offers, and their options,
     * available to order from Scaleway.
     *
     * @param request - The request {@link ListOffersRequest}
     * @returns A Promise of ListOffersResponse
     */
    listOffers: (request: Readonly<ListOffersRequest>) => Promise<ListOffersResponse>;
    protected pageOfListControlPanels: (request?: Readonly<ListControlPanelsRequest>) => Promise<ListControlPanelsResponse>;
    /**
     * "List the control panels type: cpanel or plesk.".
     *
     * @param request - The request {@link ListControlPanelsRequest}
     * @returns A Promise of ListControlPanelsResponse
     */
    listControlPanels: (request?: Readonly<ListControlPanelsRequest>) => Promise<ListControlPanelsResponse> & {
        all: () => Promise<import("./types.gen").ControlPanel[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").ControlPanel[], void, void>;
    };
    /**
     * Create a user session.
     *
     * @param request - The request {@link CreateSessionRequest}
     * @returns A Promise of Session
     */
    createSession: (request: Readonly<CreateSessionRequest>) => Promise<Session>;
    resetHostingPassword: (request: Readonly<ResetHostingPasswordRequest>) => Promise<ResetHostingPasswordResponse>;
}
/**
 * Web Hosting Classic Mailbox API.
 *
 * This API allows you to manage your mailboxes for your Web Hosting services.
 */
export declare class ClassicMailAPI extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: ScwRegion[];
    /**
     * Create a new mailbox within your hosting plan.. Create a new mailbox within
     * your hosting plan.
     *
     * @param request - The request {@link ClassicMailApiCreateMailboxRequest}
     * @returns A Promise of Mailbox
     */
    createMailbox: (request: Readonly<ClassicMailApiCreateMailboxRequest>) => Promise<Mailbox>;
    /**
     * Get a mailbox by id within your hosting plan.. Get a mailbox by id within
     * your hosting plan.
     *
     * @param request - The request {@link ClassicMailApiGetMailboxRequest}
     * @returns A Promise of Mailbox
     */
    getMailbox: (request: Readonly<ClassicMailApiGetMailboxRequest>) => Promise<Mailbox>;
    protected pageOfListMailboxes: (request: Readonly<ClassicMailApiListMailboxesRequest>) => Promise<ListMailboxesResponse>;
    /**
     * List all mailboxes within your hosting plan.. List all mailboxes within
     * your hosting plan.
     *
     * @param request - The request {@link ClassicMailApiListMailboxesRequest}
     * @returns A Promise of ListMailboxesResponse
     */
    listMailboxes: (request: Readonly<ClassicMailApiListMailboxesRequest>) => Promise<ListMailboxesResponse> & {
        all: () => Promise<Mailbox[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Mailbox[], void, void>;
    };
    deleteMailbox: (request: Readonly<ClassicMailApiDeleteMailboxRequest>) => Promise<Mailbox>;
    /**
     * Update the mailbox within your hosting plan.. Update the mailbox within
     * your hosting plan.
     *
     * @param request - The request {@link ClassicMailApiUpdateMailboxRequest}
     * @returns A Promise of Mailbox
     */
    updateMailbox: (request: Readonly<ClassicMailApiUpdateMailboxRequest>) => Promise<Mailbox>;
}
